SystemOrganization addCategory: #'Phidget-Tests'!

TestCase subclass: #PhdCrMockTestCase
	instanceVariableNames: 'layers phidget'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-Tests'!

!PhdCrMockTestCase methodsFor: 'mocking' stamp: 'lk 11/22/2009 16:00'!
computeLayers
	^ [ layers := self layerClass computeLayers ] ! !

!PhdCrMockTestCase methodsFor: 'mocking' stamp: 'lk 11/22/2009 15:50'!
layerClass
	^ self subclassResponsibility ! !

!PhdCrMockTestCase methodsFor: 'mocking' stamp: 'lk 11/22/2009 16:05'!
mainLayer
	"answer the main layer, i.e. the layer that inherits PhdMkPhidgetLayer. This layer represents the current session."
	^ layers
		ifNil: [ nil ]
		ifNotNil: [ layers
			detect: [ :layer | layer isKindOf: PhdMkPhidgetLayer ]
			ifNone: [ nil ] ]! !

!PhdCrMockTestCase methodsFor: 'mocking' stamp: 'lk 11/22/2009 16:09'!
mock
	^ self mainLayer phidgetForId: phidget id! !

!PhdCrMockTestCase methodsFor: 'mocking' stamp: 'lk 11/22/2009 15:50'!
phidgetClass
	^ self subclassResponsibility ! !

!PhdCrMockTestCase methodsFor: 'mocking' stamp: 'lk 11/22/2009 15:50'!
runCaseWith: aBlock
	"run the test with my layers activated"

	self computeLayers useAsLayersFor: aBlock. ! !

!PhdCrMockTestCase methodsFor: 'mocking' stamp: 'lk 11/22/2009 15:57'!
setUp
	phidget := self phidgetClass new.! !

!PhdCrMockTestCase methodsFor: 'mocking' stamp: 'lk 11/26/2009 20:59'!
tearDown
	"don't forget to close the phidget!!"
	phidget close.! !

PhdCrMockTestCase subclass: #PhdCrPhidgetTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-Tests'!

!PhdCrPhidgetTest methodsFor: 'mocking' stamp: 'lk 11/22/2009 15:23'!
layerClass
	^ PhdMkInterfaceKitLayer! !

!PhdCrPhidgetTest methodsFor: 'mocking' stamp: 'lk 11/22/2009 15:23'!
phidgetClass
	^ PhdCrInterfaceKit "as we cannot test the abstract PhdCrPhidget"! !

!PhdCrPhidgetTest methodsFor: 'attachment state' stamp: 'lk 11/22/2009 16:18'!
testAttachAfterOpening
	phidget open.
	self deny: phidget isAttached.
	self mock attached: true.
	self assert: phidget isAttached.! !

!PhdCrPhidgetTest methodsFor: 'attachment state' stamp: 'lk 11/22/2009 16:10'!
testAttachBeforeOpening
	self mock attached: true.
	phidget open.
	self assert: phidget isAttached.! !

!PhdCrPhidgetTest methodsFor: 'create-open-close' stamp: 'lk 11/22/2009 14:18'!
testClose
	"a phidget must be closed after closing it."
	
	phidget open.
	phidget close.
	self deny: phidget isOpen.
	! !

!PhdCrPhidgetTest methodsFor: 'create-open-close' stamp: 'lk 11/22/2009 13:09'!
testCreate
	"The mock has already been created in setUp. Now test its properties"
	
	self assert: phidget isNil not.
	self assert: phidget checkValid.
	! !

!PhdCrPhidgetTest methodsFor: 'attachment state' stamp: 'lk 11/22/2009 16:22'!
testNotAttachedAfterClosing
	self mock attached: true.
	phidget open.
	self assert: phidget isAttached.
	phidget close.
	self deny: phidget isAttached.! !

!PhdCrPhidgetTest methodsFor: 'attachment state' stamp: 'lk 11/22/2009 16:22'!
testNotAttachedIfNotAttached
	"what a nice name for this test..."
	
	self mock attached: false.
	self deny: phidget isAttached.
	phidget open.
	self deny: phidget isAttached.! !

!PhdCrPhidgetTest methodsFor: 'create-open-close' stamp: 'lk 11/22/2009 14:18'!
testOpen
	"a phidget must be opened after opening it."
	
	self deny: phidget isOpen.
	phidget open.
	self assert: phidget isOpen.
	! !

!PhdCrPhidgetTest methodsFor: 'create-open-close' stamp: 'lk 11/26/2009 20:58'!
testOpenAny
	"a phidget must have serial number -1 if openAny was called."
	
	phidget openAny.
	self assert: phidget isOpen.
	self assert: phidget serialNumber = -1.! !

!PhdCrPhidgetTest methodsFor: 'create-open-close' stamp: 'lk 11/26/2009 20:57'!
testOpenWithSerial
	"a phidget must remember its serial number after using openWithSerial:"
	
	phidget openWithSerial: 12345.
	self assert: phidget isOpen.
	self assert: phidget serialNumber = 12345.
	! !

TestCase subclass: #PhdCrPhidgetManagerTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-Tests'!

!PhdCrPhidgetManagerTest commentStamp: 'fs 7/24/2009 16:03' prior: 0!
A PhidgetPluginTest is xxxxxxxxx.


!

!PhdCrPhidgetManagerTest class methodsFor: 'dialogs' stamp: 'lk 5/31/2009 22:01'!
message: text
	"open a modal dialog window with the message in text and an OK Button.
	Return true if the user clicked 'OK', false otherwise."
	
	^ (Morph new openModal: 
		(MessageDialogWindow new
			textFont: Preferences standardDefaultTextFont;
			title: 'Running Phidget Tests';
			text: text)
		) cancelled not.! !

!PhdCrPhidgetManagerTest class methodsFor: 'dialogs' stamp: 'lk 5/31/2009 22:01'!
proceed: text
	"open a modal dialog window with the message in text and a Cancel button.
	Return false if the user clicked 'Cancel', true otherwise."
	
	^ (Morph new openModal: 
		(ProceedDialogWindow new
			textFont: Preferences standardDefaultTextFont;
			title: 'Running Phidget Tests';
			text: text)
		) cancelled not.! !

!PhdCrPhidgetManagerTest class methodsFor: 'dialogs' stamp: 'lk 5/31/2009 22:01'!
questionWithoutCancel: text
	"Show a modal dialog window asking the question is text and Buttons for Yes and No.
	Return true if the user clicked 'yes', false otherwise."
	
	^ (Morph new openModal: 
		(QuestionWithoutCancelDialogWindow new
			textFont: Preferences standardDefaultTextFont;
			title: 'Running Phidget Tests';
			text: text)
		) answer.! !

!PhdCrPhidgetManagerTest methodsFor: 'testing - close all' stamp: 'lk 11/22/2009 15:22'!
testCloseAllPhidgets
	"after closing all Phidgets there should be no more Phidgets open."
	
	PhdCrPhidgetManager allOpenedPhidgets do: [ :phidget | phidget close ].
	self assert: PhdCrPhidgetManager allOpenedPhidgets size = 0.! !
